CrashLog

Struct CrashLog 

pub struct CrashLog {
    pub regions: Vec<Region>,
    pub metadata: Metadata,
}
Set of all the Crash Log records captured on a platform.

Fields

regions: Vec<Region>

Crash Log regions captured on the platform.

metadata: Metadata

Extra information extracted alongside the Crash Log records

Implementations

Source

impl CrashLog

pub fn from_windows_event_logs(path: Option<&Path>) -> Result<Vec<Self>, Error>

Searches for any Intel Crash Log logged in the Windows event logs.

The Windows event logs typically captures the records reported through ACPI.

pub fn from_slice(s: &[u8]) -> Result<Self, Error>

Decodes a raw Crash Log binary.

pub fn to_bert(&self) -> Vec<u8>

Exports the CrashLog as a BERT file.

pub fn to_bytes(&self) -> Vec<u8>

Exports the CrashLog as a CPER file that wraps the Crash Log regions into Firmware Error Record sections.

pub fn decode_without_cm(&self) -> Node

Returns the register tree representation of the Crash Log record headers.

pub fn decode<T: CollateralTree>(&self, cm: &mut CollateralManager<T>) -> Node

Returns the register tree representation of the Crash Log record content.

Source

impl CrashLog

pub fn from_acpi_sysfs() -> Result<Self, Error>

Reads the Crash Log reported through ACPI from the linux sysfs

pub fn from_pmt_sysfs() -> Result<Self, Error>

Reads the Crash Log reported through Intel PMT from the linux sysfs