pub struct CrashLog {
pub regions: Vec<Region>,
pub metadata: Metadata,
}Expand description
Set of all the Crash Log records captured on a platform.
Fields
regions: Vec<Region>Crash Log regions captured on the platform.
metadata: MetadataExtra information extracted alongside the Crash Log records
Implementations
Sourceimpl CrashLog
impl CrashLog
Sourcepub fn from_windows_event_logs(path: Option<&Path>) -> Result<Vec<Self>, Error>
Available on Windows and crate feature extraction only.
pub fn from_windows_event_logs(path: Option<&Path>) -> Result<Vec<Self>, Error>
extraction only.Searches for any Intel Crash Log logged in the Windows event logs.
The Windows event logs typically captures the records reported through ACPI.
Sourcepub fn from_slice(s: &[u8]) -> Result<Self, Error>
pub fn from_slice(s: &[u8]) -> Result<Self, Error>
Decodes a raw Crash Log binary.
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Exports the CrashLog as a CPER file that wraps the Crash Log regions into Firmware Error Record sections.
Sourcepub fn decode_without_cm(&self) -> Node
pub fn decode_without_cm(&self) -> Node
Returns the register tree representation of the Crash Log record headers.
Sourcepub fn decode<T: CollateralTree>(&self, cm: &mut CollateralManager<T>) -> Node
Available on crate feature collateral_manager only.
pub fn decode<T: CollateralTree>(&self, cm: &mut CollateralManager<T>) -> Node
collateral_manager only.Returns the register tree representation of the Crash Log record content.
Sourceimpl CrashLog
impl CrashLog
Sourcepub fn from_acpi_sysfs() -> Result<Self, Error>
Available on Linux and crate feature std and crate feature extraction only.
pub fn from_acpi_sysfs() -> Result<Self, Error>
std and crate feature extraction only.Reads the Crash Log reported through ACPI from the linux sysfs
Sourcepub fn from_pmt_sysfs() -> Result<Self, Error>
Available on Linux and crate feature std and crate feature extraction only.
pub fn from_pmt_sysfs() -> Result<Self, Error>
std and crate feature extraction only.Reads the Crash Log reported through Intel PMT from the linux sysfs